<?php return array(
  'package' => array(
    'type' => 'library',
    'name' => 'zend',
    'version' => '8.1.0',
    'revision' => '$Revision: 10150 $',
    'path' => 'application/libraries/Zend',
    'repository' => 'socialengine.com',
    'title' => 'Zend Framework',
    'author' => 'SocialEngine Core',
    'directories' => array(
      'application/libraries/Zend',
    )
  )
) ?>
