<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Soap
 * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: Result.php 11560 2008-10-01 10:09:10Z yoshida@zend.co.jp $
 */

/**
 * Zend_Soap_Wsdl_Parser_Result
 * 
 * @category   Zend
 * @package    Zend_Soap
 */
class Zend_Soap_Wsdl_Parser_Result {
    
    public $wsdl_file = '';
    
    public $name;
    
    public $documentation;
    
    public $operations;
    
    public $portType;
    
    public $binding;
    
    public $service;
    
    public $targetNamespace;
    
    public function __construct($wsdl)
    {
        $this->wsdl_file = $wsdl;
    }
}


